<?php
/*
Plugin Name: Book an appointment
Plugin URI:  http://wpdemo.dovi42.hu/book-an-appointment-en
Description: Book an appointment using several possible locations.
Version:     1.41
Author:      Dovi42
Author URI:  http://dovi42.hu/
License:     GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: book-an-appointment
Generator:   WP Creator - http://wpcreator.hu - 2020-09-18 10:59:06
*/

if ( !defined( 'ABSPATH' ) ) exit;

if (!defined('DS')) { define( 'DS', DIRECTORY_SEPARATOR ); }

define('BOOK_AN_APPOINTMENT_961_ROOT', dirname(__FILE__));
define('BOOK_AN_APPOINTMENT_961_VERSION', '1.41');

include_once( dirname(__file__) .DS. 'libs' .DS. 'define.php');

function book_an_appointment_961_get_options() { 
	// Alapértelmezett értékek beállítása
	// Set default option values
	$defaults = array(
			'hide'    => 0,
            'holiday' => '',
            'date_format' => 'Y. F',
            'waiting' => 2,
            'filter_type' => 'fruits',
            'google_site_key' => '',
            'google_secret_key' => '',
            'calendar' => array(
                'key'     => '',
                'secret'  => '',
                'code'    => '',
                'token'   => '',
                'refresh' => '',
                'expires' => '')
		);

	// Beállított értékek beolvasása
	// Get the set plugin option values
	$options = get_option('book_an_appointment_options');

	// Ha nincs beállítva, akkor az alapértelmezett érték 
	// If not set then set the default 
	$options = wp_parse_args($options, $defaults);

	return $options;
}


function book_an_appointment_961_load_textdomain() {
    load_plugin_textdomain( 'book-an-appointment', false, basename( dirname( __file__ )) . '/languages' ); 
}
add_action( 'plugins_loaded', 'book_an_appointment_961_load_textdomain' );

function book_an_appointment_961_create_db() {

	global $wpdb;
	$charset_collate = $wpdb->get_charset_collate();
	$table_name = $wpdb->prefix . 'bookanappointment';

	$sql = "CREATE TABLE IF NOT EXISTS ".$table_name." (
		`id` int(11) NOT NULL AUTO_INCREMENT,
		`place_id` int(11) NOT NULL,
        `date` date NOT NULL,
        `time` varchar(5) NOT NULL DEFAULT '00:00', 
		`on_book` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
        `ip` varchar(15) NOT NULL,
        `token` varchar(25) NOT NULL,
		`data` text NOT NULL,
        `confirm`  varchar(20) NOT NULL DEFAULT '',
        `accept` varchar(20) NOT NULL DEFAULT '',
		UNIQUE KEY id (id)
	) $charset_collate;";

	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );
}


// Show notice 
// Üzenet megjelenítése
function book_an_appointment_961_notice() {

    if( get_transient( 'book_an_appointment_961_review_notice' ) ) {

        echo '<div class="notice notice-success"><p>' . 
                sprintf( '<strong>'.__('Book an appointment','book-an-appointment').':</strong> '.
                         __('Please don\'t forget to <a href="%s" target="_blank">rate the plugin!</a>', 'book-an-appointment'),
                        'https://wordpress.org/support/plugin/book-an-appointment/reviews/') .
             '</p></div>';
        delete_transient( 'book_an_appointment_961_review_notice' );
    }
}
add_action( 'admin_notices', 'book_an_appointment_961_notice' );


function book_an_appointment_961_activation() {
    // A plugin aktiválásakor fut le
    // Call when plugin is activated
    
	// Alapértelmezett értékek beállítása
	// Set default value(s) to options
	$options = book_an_appointment_961_get_options();
	update_option('book_an_appointment_options', $options, true);
    
    set_transient( 'book_an_appointment_961_review_notice', 1 );
    
	if( !wp_next_scheduled( 'book_an_appointment_961_cron_job' ) ) {
		wp_schedule_event( time(), 'hourly', 'book_an_appointment_961_cron_job' );
	}

    book_an_appointment_961_create_db();
    
    flush_rewrite_rules();
}
register_activation_hook( __file__, 'book_an_appointment_961_activation' );

function book_an_appointment_961_upgrade_completed( $upgrader_object, $options ) {
    $our_plugin = plugin_basename( __file__ );
    if( $options['action'] == 'update' && $options['type'] == 'plugin' && isset( $options['plugins'] ) ) {
        foreach( $options['plugins'] as $plugin ) {
            if( $plugin == $our_plugin ) {

                set_transient( 'book_an_appointment_961_review_notice', 1 );
                flush_rewrite_rules();

            }
        }
    }
}
add_action( 'upgrader_process_complete', 'book_an_appointment_961_upgrade_completed', 10, 2 );


function book_an_appointment_961_deactivation() {
    // A plugin deaktiválásakor fut le
    // Call when plugin is deactivated

	$timestamp = wp_next_scheduled ('book_an_appointment_961_cron_job');
	wp_unschedule_event ($timestamp, 'book_an_appointment_961_cron_job');
	wp_clear_scheduled_hook('book_an_appointment_961_cron_job');
    flush_rewrite_rules();
}
register_deactivation_hook( __file__, 'book_an_appointment_961_deactivation' );

function book_an_appointment_961_uninstall() {
    // A plugin törlésekor fut le
    // Call when plugin is uninstall
    global $wpdb;
    $wpdb->query('DROP TABLE IF EXISTS ' . $wpdb->prefix . 'bookanappointment');

	// Beállítások törlése
	// Delete value(s) from options
	delete_option('book_an_appointment_options');

}
register_uninstall_hook( __file__, 'book_an_appointment_961_uninstall' );

function book_an_appointment_961_shortcode($args) {

	// Alapértelmezett értékek betöltése
	// Load default option values
	$options = book_an_appointment_961_get_options();
    // $args = wp_parse_args($args, $options);
    $options['now'] = date('Y-m');
    $options['target'] = $args['target'];

	// Elviekben lehetséges többszöri meghívás, ezért a jelző csak egyszer engedi betölteni a szkripteket.
	// In principle, multiple invitations are possible, so the token will only allow you to load scripts once.
	if (!defined('BOOK_AN_APPOINTMENT_961')) {
		// A globális beállítások átadódnak a script-ek meghívásához
		// Global settings are passed to invite scripts
		book_an_appointment_961_styles_and_scripts_to_frontend();
	}

    // Osztály betöltése, ha kell
    // Load class if needed
    if (!class_exists('JBookAnAppointment961')) {
        include_once( dirname(__file__) .DIRECTORY_SEPARATOR. 'libs' .DIRECTORY_SEPARATOR. 'class.php');
    }

    // Az alapértelmezett paraméterekkel történik az optiomalizálás
    // Init to default options
    $my_plugin = new JBookAnAppointment961($options, $args);

    $html = $my_plugin->prepareContent();
    
    return $html;
}
add_shortcode('book-an-appointment', 'book_an_appointment_961_shortcode');


function book_an_appointment_961_styles_and_scripts_to_frontend()
{
    global $pagenow;

    define('BOOK_AN_APPOINTMENT_961', 1);

    // Csak a felhasználói oldalon töltődjenek be a szkriptek
    // Only load scripts on the user page
    if (in_array( $pagenow, array( 'post.php', 'page.php', 'index.php' ))) {

        wp_register_style( 'book-an-appointment', plugins_url( 'book-an-appointment/assets/css/book-an-appointment.css', BOOK_AN_APPOINTMENT_961_ROOT ), array(), BOOK_AN_APPOINTMENT_961_VERSION );
    	wp_enqueue_style( 'book-an-appointment' );
        
    	wp_register_script('book-an-appointment-js', plugins_url( 'book-an-appointment/assets/js/book-an-appointment.js', BOOK_AN_APPOINTMENT_961_ROOT ), array('jquery'), BOOK_AN_APPOINTMENT_961_VERSION, true);

		// Ajax hívás engedélyezése
		// Enable call ajax
		wp_localize_script('book-an-appointment-js', 'book_an_appointment_961_ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
		wp_enqueue_script('book-an-appointment-js');
    }
}
// add_action( 'wp_enqueue_scripts', 'book_an_appointment_961_styles_and_scripts_to_frontend' );

function book_an_appointment_961_add_asyncdefer_attribute($tag, $handle) {
    if ($handle == 'google-filter-js') {
        return str_replace( '<script ', '<script async ', $tag );
    } else {
        return $tag;
    }
}
add_filter('script_loader_tag', 'book_an_appointment_961_add_asyncdefer_attribute', 10, 2);

function book_an_appointment_961_add_async_forscript($url)
{
    if (strpos($url, 'recaptcha') === false)
        return $url;
    else if (is_admin())
        return $url;
    else
        return $url . '&render=explicit'; 
}
add_filter('clean_url', 'book_an_appointment_961_add_async_forscript', 11, 1);



if ( is_admin() ){ 

    include( dirname(__file__) .DIRECTORY_SEPARATOR. 'libs' .DIRECTORY_SEPARATOR. 'book-an-appointment-setup.php' );
    $my_settings_page = new book_an_appointment_961_settings();
    
    function book_an_appointment_961_get_extra_meta_links($meta, $file, $data, $status) {

        if (plugin_basename(__FILE__) == $file) {
            $lang = get_bloginfo('language');
            if ($lang == 'hu') {
                $url = 'http://wpdemo.dovi42.hu/book-an-appointment';
            } else {
                $url = 'http://wpdemo.dovi42.hu/book-an-appointment-en';
            } 
            $meta[] = '<a href="'.$url.'" target="_blank" title="' . __('Detailed description and examples', 'book-an-appointment') . '">'.__('Detailed description and examples', 'book-an-appointment').'</a>';

            $meta[]  = '<a href="https://wordpress.org/support/plugin/book-an-appointment/reviews/">'.
                       __('Please rating!', 'book-an-appointment') . '&nbsp;' .
                       '<span class="dashicons dashicons-star-empty dashicons-star-filled" style="color:#ffb900 !important;"></span>'.
                       '<span class="dashicons dashicons-star-empty dashicons-star-filled" style="color:#ffb900 !important;"></span>'.
                       '<span class="dashicons dashicons-star-empty dashicons-star-filled" style="color:#ffb900 !important;"></span>'.
                       '<span class="dashicons dashicons-star-empty dashicons-star-filled" style="color:#ffb900 !important;"></span>'.
                       '<span class="dashicons dashicons-star-empty dashicons-star-filled" style="color:#ffb900 !important;"></span>'.
                       '</a>';
        }
        return $meta;
    }
    add_filter("plugin_row_meta", 'book_an_appointment_961_get_extra_meta_links', 10, 4);

    global $pagenow, $post;

    $type = '';
    if (isset($_REQUEST['post_type']) and (!empty($_REQUEST['post_type']))) {
        $type = $_REQUEST['post_type'];
    }
    if ((in_array($pagenow, array('post.php', 'admin.php'))) or ($type == 'booking-place')) {
        add_action( 'admin_enqueue_scripts', 'book_an_appointment_961_styles_to_backend' );        
        include_once( dirname(__file__) .DS. 'libs' .DS. 'admin.php');
    }

    function book_an_appointment_961_register_unaccepted_menu() {
        add_submenu_page(
            'edit.php?post_type=booking-place', 
            __('Unaccepted books', 'book-an-appointment'), 
            __('Unaccepted books', 'book-an-appointment'), 
            'manage_options', 
            'awaiting_books',
            'awaiting_books_render_page'
        );
    }
    add_action('admin_menu', 'book_an_appointment_961_register_unaccepted_menu', 50);    

    function awaiting_books_render_page() {
    	wp_register_script('book-an-appointment-admin-confirmation-js', plugins_url( 'book-an-appointment/assets/js/book-an-appointment-admin-unaccepted.js', BOOK_AN_APPOINTMENT_961_ROOT ), array('jquery'));
    	wp_localize_script('book-an-appointment-admin-confirmation-js', 'book_an_appointment_961_ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
    	wp_enqueue_script('book-an-appointment-admin-confirmation-js');
        
        include_once( dirname(__file__) .DS. 'libs' .DS. 'awaiting-confirmation.php');
    }

    function book_an_appointment_961_register_browse_menu() {
        add_submenu_page(
            'edit.php?post_type=booking-place', 
            __('Browse books', 'book-an-appointment'), 
            __('Browse books', 'book-an-appointment'), 
            'manage_options', 
            'browse_books',
            'books_render_browse_page'
        );
    }
    add_action('admin_menu', 'book_an_appointment_961_register_browse_menu', 40);    

    function books_render_browse_page() {
    	wp_enqueue_script( 'jquery-ui-core', false, array('jquery') );
        wp_register_script('book-an-appointment-admin-browse-js', plugins_url( 'book-an-appointment/assets/js/book-an-appointment-admin-browse.js', BOOK_AN_APPOINTMENT_961_ROOT ), array('jquery'));
    	wp_localize_script('book-an-appointment-admin-browse-js', 'book_an_appointment_961_ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
    	wp_enqueue_script('book-an-appointment-admin-browse-js');
        
        
        include_once( dirname(__file__) .DS. 'libs' .DS. 'browse-books.php');
    }
    
}


function book_an_appointment_961_styles_to_backend() {
    wp_register_style( 'book-an-appointment-admin', plugins_url( 'book-an-appointment/assets/css/book-an-appointment-admin.css', BOOK_AN_APPOINTMENT_961_ROOT ) );
	wp_enqueue_style( 'book-an-appointment-admin' );

	wp_register_script('book-an-appointment-admin-post-js', plugins_url( 'book-an-appointment/assets/js/book-an-appointment-admin-post.js', BOOK_AN_APPOINTMENT_961_ROOT ), array('jquery'));
	wp_enqueue_script('book-an-appointment-admin-post-js');
}

// Add settings link to plugins page 
function book_an_appointment_961_add_settings_link( $links ) {
    $settings_link = '<a href="options-general.php?page=book-an-appointment-setting-admin">' . __( 'Settings' ) . '</a>';
    array_unshift( $links, $settings_link );
  	return $links;
}
$plugin = plugin_basename( __file__ );
add_filter( "plugin_action_links_$plugin", 'book_an_appointment_961_add_settings_link' );

function book_an_appointment_961_styles_and_scripts_to_backend()
{
    global $pagenow;
    
    if (isset($_REQUEST['page'])) {
        $page = sanitize_text_field($_REQUEST['page']);
    } else {
        $page = '';
    }
    // Csak akkor töltődik be, amikor ennek a pluginnak a beállításai aktuálisak.
    // It will only load when the settings for this plugin are current.
    if (($pagenow == 'options-general.php') and ($page == 'book-an-appointment-setting-admin')) {

        wp_register_style( 'book-an-appointment-admin', plugins_url( 'book-an-appointment/assets/css/book-an-appointment-admin.css', BOOK_AN_APPOINTMENT_961_ROOT ) );
    	wp_enqueue_style( 'book-an-appointment-admin' );

    	wp_register_script('book-an-appointment-admin-js', plugins_url( 'book-an-appointment/assets/js/book-an-appointment-admin.js', BOOK_AN_APPOINTMENT_961_ROOT ), array('jquery'));
    	wp_localize_script('book-an-appointment-admin-js', 'book_an_appointment_961_ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
    	wp_enqueue_script('book-an-appointment-admin-js');
        
    }
}
add_action( 'admin_enqueue_scripts', 'book_an_appointment_961_styles_and_scripts_to_backend' );

function book_an_appointment_961_cron_function() {
    global $wpdb;
    
    $options = book_an_appointment_961_get_options();
    
    $old = date('Y-m-d H:i:s', strtotime('-'.$options['waiting'].' hours', strtotime(date('Y-m-d H:i:s'))));
    $query = 'DELETE FROM ' . $wpdb->prefix.'bookanappointment ' .
                'WHERE ' . 
                    '`confirm` = "" AND ' .
                    '`on_book` < "'.$old.'"';
    $wpdb->query($wpdb->prepare($query));
}
add_action ('book_an_appointment_961_cron_job', 'book_an_appointment_961_cron_function');

include_once(BOOK_AN_APPOINTMENT_961_ROOT . '/libs/ajax.php');
include_once(BOOK_AN_APPOINTMENT_961_ROOT . '/libs/hooks.php');
include_once(BOOK_AN_APPOINTMENT_961_ROOT . '/libs/endpoints.php');


function book_an_appointment_961_send_confirmation_info($id, $info) {
    
    $emails = get_post_meta($id, 'appointment_emails', true);
    if (!empty($emails)) {
        $emails = explode(',', str_replace(' ', '', $emails));

        $headers = array('Content-Type: text/html; charset=UTF-8');
        $subject = sprintf( __('Booking confirmation - %s', 'book-an-appointment'), get_the_title($id));
    
        $data = array();
        $data['title'] = get_the_title($id);
        $data['description'] = book_an_appointment_961_get_excerpt($id);
        
        foreach ($info as $key => $value) {
            if (!in_array($key, array('date', 'time', 'link'))) {
                $data[$key] = $value;    
            }
        }    

        $data['browse_book_link'] = get_home_url().'/wp-admin/edit.php?post_type=booking-place&page=browse_books&id='.$id;
        if (!is_array($info['date'])) {
            $data['day'] = date_i18n('Y. F j., l,', strtotime($info['date']));
            $data['time'] = date_i18n('H:i', strtotime($info['time']));
            $data['days'] = '';
            $data['browse_book_link'] .= '&date='.$info['date'];
        } else {
            $data['day'] = '';
            $data['days'] = array();
            foreach ($info['date'] as $day) {
                $data['days'][] = array('day' => date_i18n('Y. F j., l,', strtotime($day)));    
            }
            $data['browse_book_link'] .='&date='.$info['date'][0];
        }

        $data['unaccepted_list_link'] = get_home_url().'/wp-admin/edit.php?post_type=booking-place&page=awaiting_books&id='.$id;
        
        $lang = book_an_appointment_961_get_lang();
        $tmpl = new JDovi42_Templates(BOOK_AN_APPOINTMENT_961_ROOT);
        $tmpl->useTemplate('emails' .DIRECTORY_SEPARATOR. $lang .DIRECTORY_SEPARATOR. 'confirmation-info-admin.html');
        $tmpl->setOptions($data);
        
        $body = $tmpl->prepareContent();

        if ($body == '') {
            return '';
        }

        wp_mail($emails, $subject, $body, $headers);
    }
    
}

function book_an_appointment_961_send_cancelled_info($id, $info) {
    
    $emails = get_post_meta($id, 'appointment_emails', true);
    if (!empty($emails)) {
        $emails = explode(',', str_replace(' ', '', $emails));

        $headers = array('Content-Type: text/html; charset=UTF-8');
        $subject = sprintf( __('Reservation canceled - %s!', 'book-an-appointment'), get_the_title($id));
    
        $data = array();
        $data['title'] = get_the_title($id);
        $data['description'] = book_an_appointment_961_get_excerpt($id);
        
        foreach ($info as $key => $value) {
            if (!in_array($key, array('date', 'time', 'link'))) {
                $data[$key] = $value;    
            }
        }    

        $data['browse_book_link'] = get_home_url().'/wp-admin/edit.php?post_type=booking-place&page=browse_books&id='.$id;
        if (!is_array($info['date'])) {
            $data['day'] = date_i18n('Y. F j., l,', strtotime($info['date']));
            $data['time'] = date_i18n('H:i', strtotime($info['time']));
            $data['days'] = '';
            $data['browse_book_link'] .= '&date='.$info['date'];
        } else {
            $data['day'] = '';
            $data['days'] = array();
            foreach ($info['date'] as $day) {
                $data['days'][] = array('day' => date_i18n('Y. F j., l,', strtotime($day)));    
            }
            $data['browse_book_link'] .='&date='.$info['date'][0];
        }
        
        $lang = book_an_appointment_961_get_lang();
        $tmpl = new JDovi42_Templates(BOOK_AN_APPOINTMENT_961_ROOT);
        $tmpl->useTemplate('emails' .DIRECTORY_SEPARATOR. $lang .DIRECTORY_SEPARATOR. 'cancelled-from-user.html');
        $tmpl->setOptions($data);

        $body = $tmpl->prepareContent();
        
        if ($body == '') {
            return '';
        }

        wp_mail($emails, $subject, $body, $headers);

    }
}

function book_an_appointment_961_get_excerpt($post_id, $size = 300) {
    
    $html = get_the_excerpt($post_id);
    
    $html = strip_tags($html);
    $html = strip_shortcodes($html);
    $source = explode(' ', $html);
    $tmp = '';
    $i = 0;
    $ok = true;
    while ((isset($source[$i])) and (mb_strlen($tmp . ' ' . $source[$i], 'UTF-8') < $size) and ($i <= (count($source)-1))) {
        $tmp .= ' ' . $source[$i];
        $i++;
    }
    if (mb_strlen($html) > $size) {
        $tmp .= ' [...]';
    }
    return $tmp;
}

function book_an_appointment_961_get_lang() {
    $lang = get_bloginfo('language');
    if (is_dir(get_stylesheet_directory() .DIRECTORY_SEPARATOR. 'book-an-appointment' .DIRECTORY_SEPARATOR. 'emails' .DIRECTORY_SEPARATOR. $lang)) {
        return $lang;
    } else {
        if (is_dir(BOOK_AN_APPOINTMENT_961_ROOT .DIRECTORY_SEPARATOR. 'templates' .DIRECTORY_SEPARATOR. 'emails' .DIRECTORY_SEPARATOR. $lang)) {
            return $lang;
        } else {
            return 'en';
        }
    }
}

function book_an_appointment_961_refresh_calendar_token() {
    
    $options = book_an_appointment_961_get_options();
    if (!empty($options['calendar']['refresh'])) {
        
        if (time() > ($options['calendar']['expires'] - 60)) {
            
            if (!class_exists('GoogleCalendarApi')) {
                include_once( BOOK_AN_APPOINTMENT_961_ROOT .DIRECTORY_SEPARATOR. 'libs' .DIRECTORY_SEPARATOR. 'google-calendar-api.php');
            }
            $capi = new GoogleCalendarApi();
            $data = $capi->GetRefreshedAccessToken($options['calendar']['key'], $options['calendar']['refresh'], $options['calendar']['secret']);
            if (isset($data['access_token'])) {
                $options['calendar']['token'] = $data['access_token'];
                $options['calendar']['expires'] = time() + $data['expires_in'];
                update_option('book_an_appointment_options', $options);
            }
        }
    }
    return $options;
}

function book_an_appointment_961_add_google_calendar($token) {
    
    global $wpdb;

    if (empty($token)) { return 'empty'; }
    
    $options = book_an_appointment_961_refresh_calendar_token();

    if (!class_exists('GoogleCalendarApi')) {
        include_once( BOOK_AN_APPOINTMENT_961_ROOT .DIRECTORY_SEPARATOR. 'libs' .DIRECTORY_SEPARATOR. 'google-calendar-api.php');
    }
    $capi = new GoogleCalendarApi();
    $user_timezone = $capi->GetUserCalendarTimezone($options['calendar']['token']);

    $sql = 'SELECT *'.
           ' FROM ' . $wpdb->prefix . 'bookanappointment' . 
           ' WHERE `token` = "'.$token.'"' .
           ' ORDER BY `id` DESC';
    $items = $wpdb->get_results($sql);
    
    if (!empty($items)) {
    
        foreach ($items as $event) {

            $calendar    = get_post_meta($event->place_id, 'appointment_calendar', true);
            $step        = get_post_meta($event->place_id, 'appointment_mins', true);
            $location = get_the_title($event->place_id); 

            if (!empty($calendar)) {
        
                if ($event->time != '00:00') {
                    $full_day_event = 0;
                    $off = date('H:i:s', strtotime('+'.($step-1).' mins', strtotime($event->time)));
                    $event_time = [ 'start_time' => $event->date.'T'.$event->time.':00', 'end_time' => $event->date.'T'.$off ];
                } else {
                    $full_day_event = 1; 
                    $event_time = [ 'event_date' => $event->date ];
                }
                
                $description = unserialize($event->data);
                $description = (array) $description;
                $keys = array_keys($description);
                $event_title = $description[$keys[0]];
                $description = apply_filters('book_an_appointment_961_booking_content', $event->data);
    
                $event_id = $capi->CreateCalendarEvent($calendar, $event_title, $description, $location, $full_day_event, $event_time, $user_timezone, $options['calendar']['token']);
    
                $sql = 'UPDATE ' . $wpdb->prefix . 'bookanappointment' . 
                       ' SET ' . 
                        '`calendar_id` = "'.$event_id.'"' .
                       ' WHERE `id` = "'.$event->id.'"';
                $wpdb->query($sql);
            }
        }
        
        return null;
    }
    return 'empty';
}

function book_an_appointment_961_remove_google_calendar($token) {
    
    global $wpdb;

    if (empty($token)) { return 'empty'; }
    
    $options = book_an_appointment_961_refresh_calendar_token();

    if (!class_exists('GoogleCalendarApi')) {
        include_once( BOOK_AN_APPOINTMENT_961_ROOT .DIRECTORY_SEPARATOR. 'libs' .DIRECTORY_SEPARATOR. 'google-calendar-api.php');
    }
    $capi = new GoogleCalendarApi();
    $user_timezone = $capi->GetUserCalendarTimezone($options['calendar']['token']);

    $sql = 'SELECT *'.
           ' FROM ' . $wpdb->prefix . 'bookanappointment' . 
           ' WHERE `token` = "'.$token.'"' .
           ' ORDER BY `id` DESC';
    $items = $wpdb->get_results($sql);
    
    if (!empty($items)) {
    
        foreach ($items as $event) {

            if ((isset($event->calendar_id)) and (!empty($event->calendar_id))) {
                
                $calendar = get_post_meta($event->place_id, 'appointment_calendar', true);
                $capi->DeleteCalendarEvent($event->calendar_id, $calendar, $options['calendar']['token']);

                $sql = 'UPDATE ' . $wpdb->prefix . 'bookanappointment' . 
                       ' SET ' . 
                        '`calendar_id` = ""' .
                       ' WHERE `id` = ""';
                $wpdb->query($sql);
                
            }
        }
        
        return null;
    }
    return 'empty';
}


   
$text = __('<strong>Error!</strong> Token not set.', 'book-an-appointment');    
$text = __('This reservation is not in our system.<br /><small>It is possible that it was confirmed too late, or the confirmation link is broken.</small>', 'book-an-appointment');
$text = __('This reservation has been previously confirmed.', 'book-an-appointment');
$text = __('Reservation confirmed successfully.', 'book-an-appointment');
$text = __('The reservation has been canceled.', 'book-an-appointment');

