<?php

if ( !defined( 'ABSPATH' ) ) exit;

class book_an_appointment_961_settings
{
    private $options;

    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

    public function add_plugin_page()
    {
        // This page will be under "Settings"
        add_options_page(
            'Settings Admin', 
            __('Book an appointment settings', 'book-an-appointment'), 
            'manage_options', 
            'book-an-appointment-setting-admin', 
            array( $this, 'create_admin_page' )
        );
    }

    public function create_admin_page()
    {
        $this->options = book_an_appointment_961_get_options ( 'book_an_appointment_options' );
        ?>
        <style>.form-table td {padding: 0px 10px 0 10px;}</style>
        <div class="wrap">
            <h1><?php echo __('Book an appointment settings', 'book-an-appointment');?></h1>
            <?php
                $active_tab = isset( $_GET[ 'book-an-appointment-tab' ] ) ? sanitize_text_field($_GET[ 'book-an-appointment-tab' ]) : 'readme';
            ?>
            <h2 class="nav-tab-wrapper">
                <a href="?page=book-an-appointment-setting-admin&book-an-appointment-tab=readme" class="nav-tab  <?php echo $active_tab == 'readme' ? 'nav-tab-active' : ''; ?>"><?php echo __('Using plugin', 'book-an-appointment');?></a>
                <a href="?page=book-an-appointment-setting-admin&book-an-appointment-tab=settings" class="nav-tab  <?php echo $active_tab == 'settings' ? 'nav-tab-active' : ''; ?>"><?php echo __('Plugin settings', 'book-an-appointment');?></a>
                <a href="?page=book-an-appointment-setting-admin&book-an-appointment-tab=calendar" class="nav-tab  <?php echo $active_tab == 'calendar' ? 'nav-tab-active' : ''; ?>"><?php echo __('Google calendar', 'book-an-appointment');?></a>
            </h2>
            <div class="book-an-appointment-setting-page">
                <div>
            <?php
                switch ($active_tab){ 

                    case 'settings':
                        ?>
                        <form method="post" action="options.php">
                        <?php
                            // This prints out all hidden setting fields
                            settings_fields( 'book_an_appointment_option_main' );
                            do_settings_sections( 'book-an-appointment-setting-admin' );
                            submit_button();
                        ?>
                        </form>
                        <?php
                        break;

                    case 'calendar':
                        include( dirname(__FILE__) . DIRECTORY_SEPARATOR . 'calendar-setup.php' );
                        break;


                    default: 
                        echo '<h3>' . __('Insert to the content', 'book-an-appointment'). '</h3>';
                        include( dirname(__FILE__) . DIRECTORY_SEPARATOR . 'how_to_use.php' );
                        /*
                            or 
                            include( dirname(__FILE__) . DIRECTORY_SEPARATOR . 'how_to_use_'.get_bloginfo('language').'.php' );
                            // include ./how_to_use_en.php
                        */
                }
            ?>
                </div>
            </div>
        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {        
        register_setting(
            'book_an_appointment_option_main', // Option group
            'book_an_appointment_options', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

        add_settings_section(
            'book_an_appointment_settings_main', // ID
            __('Book an appointment Custom Settings', 'book-an-appointment'), // Title
            array( $this, 'print_section_info' ), // Callback
            'book-an-appointment-setting-admin' // Page
        );  

        add_settings_field(
            'hide', // ID
            __('Hide in search', 'book-an-appointment'), // Title
            array( $this, 'hide_callback' ), // Callback
            'book-an-appointment-setting-admin', // Page
            'book_an_appointment_settings_main' // Section
        );

        add_settings_field(
            'holiday', // ID
            __('Holiday days', 'book-an-appointment'), // Title
            array( $this, 'holiday_callback' ), // Callback
            'book-an-appointment-setting-admin', // Page
            'book_an_appointment_settings_main' // Section
        );

        add_settings_field(
            'date_format', // ID
            __('Date format', 'book-an-appointment'), // Title
            array( $this, 'date_callback' ), // Callback
            'book-an-appointment-setting-admin', // Page
            'book_an_appointment_settings_main' // Section
        );

        add_settings_field(
            'waiting', // ID
            __('Waiting for confirmation', 'book-an-appointment'), // Title
            array( $this, 'waiting_callback' ), // Callback
            'book-an-appointment-setting-admin', // Page
            'book_an_appointment_settings_main' // Section
        );

        add_settings_field(
            'google_site_key', // ID
            __('Site key for Google reCAPTHA', 'book-an-appointment'), // Title
            array( $this, 'google_site_key_callback' ), // Callback
            'book-an-appointment-setting-admin', // Page
            'book_an_appointment_settings_main' // Section
        );

        add_settings_field(
            'google_secret_key', // ID
            __('Secret key for Google reCAPTHA', 'book-an-appointment'), // Title
            array( $this, 'google_secret_key_callback' ), // Callback
            'book-an-appointment-setting-admin', // Page
            'book_an_appointment_settings_main' // Section
        );


    }

    public function sanitize( $input )
    {
        $new_input = array();

        if ( isset( $input['hide'] ) ) {
            $new_input['hide'] = 1;
        } else {
            $new_input['hide'] = 0;
        }

        if ( isset( $input['holiday'] ) ) {
            $new_input['holiday'] = trim( $input['holiday'] );
        }
        if ( isset( $input['free'] ) ) {
            $new_input['free'] = trim( $input['free'] );
        }
        if ( isset( $input['work'] ) ) {
            $new_input['work'] = trim( $input['work'] );
        }
        if ( isset( $input['date_format'] ) ) {
            $new_input['date_format'] = trim( $input['date_format'] );
        }
        if ( isset( $input['waiting'] ) ) {
            $w = trim( $input['waiting'] );
            if (!is_int($w)) { $w = 2; }
            $new_input['waiting'] = $w;
        }
        if ( isset( $input['google_site_key'] ) ) {
            $new_input['google_site_key'] = trim( $input['google_site_key'] );
        }
        if ( isset( $input['google_secret_key'] ) ) {
            $new_input['google_secret_key'] = trim( $input['google_secret_key'] );
        }
        if (!empty($new_input['google_site_key']) and !empty($new_input['google_secret_key'])) {
            $new_input['filter_type'] = 'google';
        } else {
            $new_input['filter_type'] = 'fruits';
        }

        $new_input['calendar']['key'] = $input['calendar']['key'];
        $new_input['calendar']['secret'] = $input['calendar']['secret'];
        $new_input['calendar']['code'] = $input['calendar']['code'];
        $new_input['calendar']['token'] = $input['calendar']['token'];
        $new_input['calendar']['refresh'] = $input['calendar']['refresh'];
        $new_input['calendar']['expires'] = $input['calendar']['expires'];

        return $new_input;
    }

    public function print_section_info()
    {
        print __('Set working day relocations for holidays!', 'book-an-appointment');
    }

    public function hide_callback()
    {
        if ($this->options['hide'] == 1) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';
        } 
        printf(
            '<input type="checkbox" id="book_an_appointment_hide" name="book_an_appointment_options[hide]" value="1" '.$checked.' />' .
            '<label for="book_an_appointment_hide"></label>' .
            '<small>'.__('Do not show bookings in search results.', 'book-an-appointment').'</small>',
            isset( $this->options['hide'] ) ? esc_attr( $this->options['hide']) : ''
        );
        echo '<div style="clear:both;margin-bottom:10px;"></div>';
        printf(
            '<input type="hidden" name="book_an_appointment_options[calendar][key]" value="%s" />',
             $this->options['calendar']['key']);
        printf(
            '<input type="hidden" name="book_an_appointment_options[calendar][secret]" value="%s" />',
             $this->options['calendar']['secret']);
        printf(
            '<input type="hidden" name="book_an_appointment_options[calendar][code]" value="%s" />',
             $this->options['calendar']['code']);
        printf(
            '<input type="hidden" name="book_an_appointment_options[calendar][token]" value="%s" />',
             $this->options['calendar']['token']);
        printf(
            '<input type="hidden" name="book_an_appointment_options[calendar][refresh]" value="%s" />',
             $this->options['calendar']['refresh']);
        printf(
            '<input type="hidden" name="book_an_appointment_options[calendar][expires]" value="%s" />',
             $this->options['calendar']['expires']);
    }


    public function holiday_callback()
    {
        printf(
            '<textarea name="book_an_appointment_options[holiday]">%s</textarea>' .
            '<br /><small>'.__('Comma-separated list of holidays. <em>(Ex: 2020-08-20, 2020-10-23)</em>', 'book-an-appointment').'</small>',
            isset( $this->options['holiday'] ) ? esc_attr( $this->options['holiday']) : ''
        );
        echo '<div style="clear:both;margin-bottom:10px;"></div>';
    }

    public function free_callback()
    {
        printf(
            '<textarea name="book_an_appointment_options[free]">%s</textarea>' .
            '<br /><small>'.__('Days that will be days off due to festive work schedules.', 'book-an-appointment').'</small>',
            isset( $this->options['free'] ) ? esc_attr( $this->options['free']) : ''
        );
        echo '<br /><small>'.__('List of weekends separated by commas. (Ex: 2020-08-21, 2020-12-24)', 'book-an-appointment').'</small>';
        echo '<div style="clear:both;margin-bottom:10px;"></div>';
        
    }

    public function work_callback()
    {
        printf(
            '<textarea name="book_an_appointment_options[work]">%s</textarea>' .
            '<br /><small>'.__('Days that will be working days due to a holiday schedule.', 'book-an-appointment').'</small>',
            isset( $this->options['work'] ) ? esc_attr( $this->options['work']) : ''
        );
        echo '<br /><small>'.__('List of working days separated by commas. (Ex: 2020-08-29, 2020-12-12)', 'book-an-appointment').'</small>';
        echo '<div style="clear:both;margin-bottom:10px;"></div>';
    }

    public function date_callback()
    {
        printf(
            '<input type="text" name="book_an_appointment_options[date_format]" value="%s" />' .
            '<br /><small>'.
            __('<a href="https://wordpress.org/support/article/formatting-date-and-time/" target="_blank">'.__('Documentation on date and time formatting.', 'book-an-appointment').'</a>').'</small>',
            isset( $this->options['date_format'] ) ? esc_attr( $this->options['date_format']) : ''
        );
        echo '<div style="clear:both;margin-bottom:10px;"></div>';
    }

    public function waiting_callback()
    {
        printf(
            '<input type="number" class="waiting" name="book_an_appointment_options[waiting]" value="%s" style="width:80px;" /> ' . __('hour(s)', 'book-an-appointment'),
            isset( $this->options['waiting'] ) ? esc_attr( $this->options['waiting']) : ''
        );
        echo '<br /><small>'.__('This number of hours must be confirmed after booking, otherwise the booking will be canceled automatically.', 'book-an-appointment').'</small>';    
        echo '<div style="clear:both;margin-bottom:10px;"></div>';
    }

    public function google_site_key_callback()
    {
        printf(
            '<input type="text" class="google_site_key" name="book_an_appointment_options[google_site_key]" value="%s" style="width:300px;" /> ',
            isset( $this->options['google_site_key'] ) ? esc_attr( $this->options['google_site_key']) : ''
        );
        echo '<br /><small>'.
             __('If left blank, it will use its own robot filter. ', 'book-an-appointment').'<br />' . 
             '<a href="https://www.google.com/recaptcha/admin/create" target="_blank">' . 
             __('You can register an v2 API key here.', 'book-an-appointment').'</a></small>';
        echo '<div style="clear:both;margin-bottom:10px;"></div>';
    }

    public function google_secret_key_callback()
    {
        printf(
            '<input type="text" class="google_secret_key" name="book_an_appointment_options[google_secret_key]" value="%s" style="width:300px;" /> ',
            isset( $this->options['google_secret_key'] ) ? esc_attr( $this->options['google_secret_key']) : ''
        );
        echo '<br /><small>'.
             __('If left blank, it will use its own robot filter. ', 'book-an-appointment') . '</small>'; 
        echo '<div style="clear:both;margin-bottom:10px;"></div>';
    }

}
