<?php
/*
Class Name:  Gallery Meta Box
Version:     0.01
Author:      Dovi42
Author URI:  http://dovi42.hu/
License:     All rights reserved 
*/

if ( ! class_exists( 'Dovi42_Appointment_Meta_Box') ) :

    class Dovi42_Appointment_Meta_Box {
        
        private $_path = '';
        
        private $_config = array(
                'id'       => 'custom_meta_box',
                'title'    => 'Custom Box',
                'pages'    => array('post', 'page'),
                'context'  => 'normal',            
                'priority' => 'high',    
                'meta_key' => 'appointment',
                'fields'   => array()
            );
        private $fields = array();
        
        
        public function __construct ( $options ) {
        
            // If we are not in admin area exit.
            if ( ! is_admin() ) { return; }
            
            $this->_config = wp_parse_args($options, $this->_config);
            $this->_path = dirname( __file__ );

            foreach ($this->_config['fields'] as $field) {
                $this->addField($field);
            }

            add_action( 'add_meta_boxes', array( $this, 'add' ) );
            add_action( 'save_post', array( $this, 'save' ) );
            add_action( 'admin_enqueue_scripts', array( $this, 'load_scripts_and_styles' ) );
        }
        
        function addField($field){
            if ((isset($field['type'])) and (!empty($field['type']))) {
                require_once( dirname(__file__) . '/inputs/'.$field['type'].'.php' );                
            }
            $field['meta_key'] = $this->_config['meta_key'];
                switch ($field['type']){ 
                    case 'label':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Label($field);
                        break;
                    case 'separator':
                        $this->fields[] = new Dovi42_Meta_Box_Separator($field);
                        break;
                    case 'text':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Text($field);
                        break;
                    case 'number':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Number($field);
                        break;
                    case 'phone':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Phone($field);
                        break;
                    case 'email':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Email($field);
                        break;
                    case 'link':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Link($field);
                        break;
                    case 'textarea':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Textarea($field);
                        break;
                    case 'range':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Range($field);
                        break;
                    case 'date':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Date($field);
                        break;
                    case 'time':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Time($field);
                        break;
                    case 'checkbox':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Checkbox($field);
                        break;
                    case 'checkboxs':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Checkboxs($field);
                        break;
                    case 'radio':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Radio($field);
                        break;
                    case 'select':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Select($field);
                        break;
                    case 'optgroup':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Optgroup($field);
                        break;
                    case 'array':
                        $this->fields[] = new Dovi42_Meta_Box_Input_Array($field);
                        break;
                    case 'usergroups':
                        $this->fields[] = new Dovi42_Meta_Box_Input_UserGroups($field);
                        break;
                    case 'userlist':
                        $this->fields[] = new Dovi42_Meta_Box_Input_UserList($field);
                        break;
                    
                    default :
                }                
        }

        function load_scripts_and_styles() {
    
        	if (file_exists(dirname(__file__) . '/libs/custom-meta-box/js/custom.js')) {
                wp_enqueue_script('cmb-custom-js', plugins_url('custom-meta-box/js/custom.js', $this->_path), array('jquery') );
            }
        	if (file_exists(dirname(__file__) . '/libs/custom-meta-box/css/custom.css')) {
                wp_register_style('cmb-custom-css', plugins_url('custom-meta-box/css/custom.css', $this->_path) );
                wp_enqueue_style( 'cmb-custom-css' );
            }
        }
    
        public function add($postType) {
            if(in_array($postType, $this->_config['pages'])){
                add_meta_box( 
                    $this->_config['id'], 
                    $this->_config['title'], 
                    array( $this, 'show' ),
                    $postType, 
                    $this->_config['context'], 
                    $this->_config['priority'] );
            }
        }
    

        public function show() {
            
            global $post;

            wp_nonce_field( basename(__FILE__), 'custom_meta_box_nonce' );

            if (!empty($this->fields)) {
                echo '<table class="custom-meta-box" style="width:100%;">';
                foreach ($this->fields as $field) {
                    echo $field->render($post->ID);                    
                }
                echo '</table>';
            }
            
            //$value = get_post_meta($post->ID, $this->_config['meta_key'], true);
            $html = '';
         
        	echo $html;
            
        }

        public function save( $post_id ) {
        
            global $post_type;
            
            $post_type_object = get_post_type_object( $post_type );
        
            if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )                      // Check Autosave
            || ( ! isset( $_POST['post_ID'] ) || $post_id != $_POST['post_ID'] )        // Check Revision
            || ( ! in_array( $post_type, $this->_config['pages'] ) )                    // Check if current post type is supported.
            || ( ! check_admin_referer( basename( __FILE__ ), 'custom_meta_box_nonce') )    // Check nonce - Security
            || ( ! current_user_can( $post_type_object->cap->edit_post, $post_id ) ) )  // Check permission
            {
                return $post_id;
            }

            if (!empty($this->fields)) {
                foreach ($this->fields as $field) {
                    $field->save($post_id);
                }
            }
/*
            if (isset($_POST[$this->_config['meta_key']])) {
            
            	if ( get_post_meta( $post_id, $this->_config['meta_key'], false ) ) {
            		update_post_meta( $post_id, $this->_config['meta_key'], $_POST[$this->_config['meta_key']] );
            	} else {
            		add_post_meta( $post_id, $this->_config['meta_key'], $_POST[$this->_config['meta_key']] );
            	}
            } 
*/
        	return $post_id;
            

        }

        private function getToken()
        {
            $chars = 'ABCDEFGHIJKLMNOPQURSTXYVWZ0123456789';
            $token = '';
            for ($i = 1; $i <= 10; $i++) {
            	$token .= substr($chars, rand(0, strlen($chars)-1), 1);
            }                
            return $token;
        }
    
    }

endif;